summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmviewlayoutmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmviewlayoutmanager.cpp')
-rw-r--r--kpovmodeler/pmviewlayoutmanager.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kpovmodeler/pmviewlayoutmanager.cpp b/kpovmodeler/pmviewlayoutmanager.cpp
index fe3a031d..1314ec85 100644
--- a/kpovmodeler/pmviewlayoutmanager.cpp
+++ b/kpovmodeler/pmviewlayoutmanager.cpp
@@ -443,7 +443,7 @@ void PMViewLayout::normalize( )
PMViewLayout PMViewLayout::extractViewLayout( PMShell* shell )
{
- PMViewLayout layout;
+ PMViewLayout tqlayout;
TQValueList< TQValueList< PMViewLayoutEntry > > cols;
cols.append( TQValueList< PMViewLayoutEntry >( ) );
@@ -457,7 +457,7 @@ PMViewLayout PMViewLayout::extractViewLayout( PMShell* shell )
for( cit = cols.begin( ); cit != cols.end( ); ++cit )
for( eit = ( *cit ).begin( ); eit != ( *cit ).end( ); ++eit )
- layout.addEntry( *eit );
+ tqlayout.addEntry( *eit );
// find floating widgets
TQPtrList<PMDockWidget> list;
@@ -495,11 +495,11 @@ PMViewLayout PMViewLayout::extractViewLayout( PMShell* shell )
invalid = true;
if( !invalid )
- layout.addEntry( e );
+ tqlayout.addEntry( e );
}
}
- return layout;
+ return tqlayout;
}
void PMViewLayout::recursiveExtractColumns(
@@ -663,10 +663,10 @@ void PMViewLayoutManager::loadData( )
m_layoutsLoaded = true;
- TQString fileName = locate( "data", "kpovmodeler/viewlayouts.xml" );
+ TQString fileName = locate( "data", "kpovmodeler/viewtqlayouts.xml" );
if( fileName.isEmpty( ) )
{
// Generate a default layout
// I have a feeling this shouldn't be here but hey, it works for now
// TODO Must find a way to move this cleanly to PMShell
PMViewLayout a;
@@ -710,7 +710,7 @@ void PMViewLayoutManager::loadData( )
TQFile file( fileName );
if( !file.open( IO_ReadOnly ) )
{
- kdError( PMArea ) << i18n( "Could not open the view layouts file." )
+ kdError( PMArea ) << i18n( "Could not open the view tqlayouts file." )
<< endl;
return;
}
@@ -740,16 +740,16 @@ void PMViewLayoutManager::loadData( )
void PMViewLayoutManager::saveData( )
{
- TQString fileName = locateLocal( "data", "kpovmodeler/viewlayouts.xml" );
+ TQString fileName = locateLocal( "data", "kpovmodeler/viewtqlayouts.xml" );
if( fileName.isEmpty( ) )
{
- kdError( PMArea ) << i18n( "View layouts not found." ) << endl;
+ kdError( PMArea ) << i18n( "View tqlayouts not found." ) << endl;
return;
}
TQFile file( fileName );
if( !file.open( IO_WriteOnly ) )
{
- kdError( PMArea ) << i18n( "Could not open the view layouts file." )
+ kdError( PMArea ) << i18n( "Could not open the view tqlayouts file." )
<< endl;
return;
}
@@ -763,7 +763,7 @@ void PMViewLayoutManager::saveData( )
{
TQDomElement l;
- l = doc.createElement( "viewlayout" );
+ l = doc.createElement( "viewtqlayout" );
( *it ).saveData( l, doc );
e.appendChild( l );
}
@@ -810,7 +810,7 @@ void PMViewLayoutManager::displayLayout( const TQString& name, PMShell* shell )
flist.remove( );
}
}
// Create the new layout
v_layout->displayLayout( shell );
m_layoutDisplayed = true;
}
@@ -866,12 +866,12 @@ void PMViewLayoutManager::removeLayout( const TQString& name )
}
-PMSaveViewLayoutDialog::PMSaveViewLayoutDialog( PMShell* parent,
+PMSaveViewLayoutDialog::PMSaveViewLayoutDialog( PMShell* tqparent,
const char* name )
- : KDialogBase( parent, name, true, i18n( "Save View Layout" ),
+ : KDialogBase( tqparent, name, true, i18n( "Save View Layout" ),
KDialogBase::Ok | KDialogBase::Cancel )
{
- m_pShell = parent;
+ m_pShell = tqparent;
setButtonOK( KStdGuiItem::save() );
enableButtonOK( false );
@@ -879,7 +879,7 @@ PMSaveViewLayoutDialog::PMSaveViewLayoutDialog( PMShell* parent,
TQWidget* w = new TQWidget( this );
TQVBoxLayout* vl = new TQVBoxLayout( w, 0, KDialog::spacingHint( ) );
- TQLabel* l = new TQLabel( i18n( "Enter view layout name:" ), w );
+ TQLabel* l = new TQLabel( i18n( "Enter view tqlayout name:" ), w );
vl->addWidget( l );
m_pLayoutName = new TQLineEdit( w );
@@ -907,13 +907,13 @@ void PMSaveViewLayoutDialog::slotOk( )
TQString name = m_pLayoutName->text( );
PMViewLayoutManager* m = PMViewLayoutManager::theManager( );
- PMViewLayout* layout = m->findLayout( name );
+ PMViewLayout* tqlayout = m->findLayout( name );
PMViewLayout newLayout = PMViewLayout::extractViewLayout( m_pShell );
newLayout.setName( name );
- if( layout )
- *layout = newLayout;
+ if( tqlayout )
+ *tqlayout = newLayout;
else
m->addLayout( newLayout );
@@ -663,10 +663,10 @@ void PMViewLayoutManager::loadData( )
if( fileName.isEmpty( ) )
{
- // Generate a default layout
+ // Generate a default tqlayout
// I have a feeling this shouldn't be here but hey, it works for now
// TODO Must find a way to move this cleanly to PMShell
@@ -810,7 +810,7 @@ void PMViewLayoutManager::displayLayout( const TQString& name, PMShell* shell )
}
}
- // Create the new layout
+ // Create the new tqlayout
v_layout->displayLayout( shell );
m_layoutDisplayed = true;